summaryrefslogtreecommitdiff
path: root/lib/rubygems/indexer.rb
diff options
context:
space:
mode:
authorglass <glass@b2dd03c8-39d4-4d8f-98ff-823fe69b080e>2015-05-10 03:01:18 +0000
committerglass <glass@b2dd03c8-39d4-4d8f-98ff-823fe69b080e>2015-05-10 03:01:18 +0000
commit0c14c3ab0b1bbf3f2a5b2c0accb2a53528635e44 (patch)
tree7035e3f5f6b57521cc5f7e1ba7688f27b97ba10f /lib/rubygems/indexer.rb
parentf64ac5d4cd1b96fb71da0955ea9f322e8feac290 (diff)
* ext/win32ole/win32ole_variant.c: fix typo "indicies".
the patch is from davydovanton <antondavydov.o at gmail.com>. [fix GH-892] * lib/rubygems/indexer.rb: ditto. * test/rubygems/test_gem_indexer.rb: ditto. git-svn-id: svn+ssh://ci.ruby-lang.org/ruby/trunk@50459 b2dd03c8-39d4-4d8f-98ff-823fe69b080e
Diffstat (limited to 'lib/rubygems/indexer.rb')
-rw-r--r--lib/rubygems/indexer.rb32
1 files changed, 16 insertions, 16 deletions
diff --git a/lib/rubygems/indexer.rb b/lib/rubygems/indexer.rb
index 8933251b75..99938d013a 100644
--- a/lib/rubygems/indexer.rb
+++ b/lib/rubygems/indexer.rb
@@ -93,16 +93,16 @@ class Gem::Indexer
end
##
- # Build various indicies
+ # Build various indices
- def build_indicies
+ def build_indices
Gem::Specification.dirs = []
Gem::Specification.add_specs(*map_gems_to_specs(gem_file_list))
build_marshal_gemspecs
- build_modern_indicies if @build_modern
+ build_modern_indices if @build_modern
- compress_indicies
+ compress_indices
end
##
@@ -169,9 +169,9 @@ class Gem::Indexer
end
##
- # Builds indicies for RubyGems 1.2 and newer. Handles full, latest, prerelease
+ # Builds indices for RubyGems 1.2 and newer. Handles full, latest, prerelease
- def build_modern_indicies
+ def build_modern_indices
specs = Gem::Specification.reject { |s| s.default_gem? }
prerelease, released = specs.partition { |s|
@@ -221,14 +221,14 @@ class Gem::Indexer
end
##
# Compresses indicies on disk
#--
# All future files should be compressed using gzip, not deflate
- def compress_indicies
- say "Compressing indicies"
+ def compress_indices
+ say "Compressing indices"
- Gem.time 'Compressed indicies' do
+ Gem.time 'Compressed indices' do
if @build_modern then
gzip @specs_index
gzip @latest_specs_index
@@ -276,12 +276,12 @@ class Gem::Indexer
end
##
# Builds and installs indicies.
def generate_index
make_temp_directories
- build_indicies
- install_indicies
+ build_indices
+ install_indices
rescue SignalException
ensure
FileUtils.rm_rf @directory
@@ -297,9 +297,9 @@ class Gem::Indexer
end
##
- # Install generated indicies into the destination directory.
+ # Install generated indices into the destination directory.
- def install_indicies
+ def install_indices
verbose = Gem.configuration.really_verbose
say "Moving index into production dir #{@dest_directory}" if verbose
@@ -389,7 +389,7 @@ class Gem::Indexer
@prerelease_specs_index)
end
- compress_indicies
+ compress_indices
verbose = Gem.configuration.really_verbose
@@ -221,14 +221,14 @@ class Gem::Indexer
end
##
- # Compresses indicies on disk
+ # Compresses indices on disk
#--
# All future files should be compressed using gzip, not deflate
@@ -276,12 +276,12 @@ class Gem::Indexer
end
##
- # Builds and installs indicies.
+ # Builds and installs indices.
def generate_index
make_temp_directories